@@ -5,19 +5,19 @@ __all__ = [
 ]
 
 from . import (
-    OriginTableCommand,
+    OriginPagedTableCommand,
     tables,
 )
 
 
-class cmd_list_files(OriginTableCommand):
+class cmd_files(OriginPagedTableCommand):
     """List files."""
 
     def execute(self, origin, options, target):
         table = tables.FilesTable()
-        print(table.render(target, origin.Files))
+        return table.render(target, origin.Files.read())
 
 
 def register(parser):
     """Register profile commands with the given parser."""
-    cmd_list_files.register(parser)
+    cmd_files.register(parser)
