@@ -9,13 +9,13 @@ from ...testing import TestCase
 from ...utils.tests.test_profiles import make_profile
 
 
-class TestLoginBase(TestCase):
-    """Tests for `cmd_login_base`."""
+class TestLogin(TestCase):
+    """Tests for `cmd_login`."""
 
     def test_print_whats_next(self):
         profile = make_profile()
         stdout = self.patch(sys, "stdout", StringIO())
-        profiles.cmd_login_base.print_whats_next(profile)
+        profiles.cmd_login.print_whats_next(profile)
         expected = dedent("""\
             Congratulations! You are logged in to the MAAS
             server at {profile.url} with the profile name
@@ -23,7 +23,7 @@ class TestLoginBase(TestCase):
 
             For help with the available commands, try:
 
-              maas --help
+              maas help
 
             """).format(profile=profile)
         observed = stdout.getvalue()
