@@ -1,3 +1,17 @@
+# Copyright 2016-2017 Canonical Ltd.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """Tests for `maas.client.utils`."""
 
 import base64
@@ -12,6 +26,7 @@ from testtools.matchers import (
     Equals,
     Is,
     MatchesListwise,
+    MatchesStructure,
 )
 from twisted.internet.task import Clock
 
@@ -240,26 +255,27 @@ class TestPayloadPreparationWithFiles(TestCase):
 class TestDocstringParsing(TestCase):
     """Tests for docstring parsing with `parse_docstring`."""
 
-    scenarios = (
-        ("normal", dict(parse=utils.parse_docstring)),
-    )
-
     def test_basic(self):
         self.assertEqual(
             ("Title", "Body"),
-            self.parse("Title\n\nBody"))
+            utils.parse_docstring("Title\n\nBody"))
         self.assertEqual(
             ("A longer title", "A longer body"),
-            self.parse("A longer title\n\nA longer body"))
+            utils.parse_docstring("A longer title\n\nA longer body"))
+
+    def test_returns_named_tuple(self):
+        self.assertThat(
+            utils.parse_docstring("Title\n\nBody"),
+            MatchesStructure.byEquality(title="Title", body="Body"))
 
     def test_no_body(self):
         # parse_docstring returns an empty string when there's no body.
         self.assertEqual(
             ("Title", ""),
-            self.parse("Title\n\n"))
+            utils.parse_docstring("Title\n\n"))
         self.assertEqual(
             ("Title", ""),
-            self.parse("Title"))
+            utils.parse_docstring("Title"))
 
     def test_unwrapping(self):
         # parse_docstring unwraps the title paragraph, and dedents the body
@@ -268,7 +284,7 @@ class TestDocstringParsing(TestCase):
             ("Title over two lines",
              "Paragraph over\ntwo lines\n\n"
              "Another paragraph\nover two lines"),
-            self.parse("""
+            utils.parse_docstring("""
                 Title over
                 two lines
 
@@ -289,17 +305,17 @@ class TestDocstringParsing(TestCase):
             """
         self.assertEqual(
             ("Title.", "Body."),
-            self.parse(example))
+            utils.parse_docstring(example))
 
     def test_normalises_whitespace(self):
         # parse_docstring can parse CRLF/CR/LF text, but always emits LF (\n,
         # new-line) separated text.
         self.assertEqual(
             ("long title", ""),
-            self.parse("long\r\ntitle"))
+            utils.parse_docstring("long\r\ntitle"))
         self.assertEqual(
             ("title", "body1\n\nbody2"),
-            self.parse("title\n\nbody1\r\rbody2"))
+            utils.parse_docstring("title\n\nbody1\r\rbody2"))
 
 
 class TestFunctions(TestCase):
@@ -437,3 +453,15 @@ class TestRetries(TestCase):
         self.assertRetry(clock, next(gen_retries), 103.5, -98.5, 0.0)
         # All done.
         self.assertRaises(StopIteration, next, gen_retries)
+
+
+class TestRemoveNone(TestCase):
+    """Test `remove_None`."""
+
+    def test_removes_all_None_values(self):
+        data = {
+            'None': None,
+            'another_None': None,
+            'keep': 'value'
+        }
+        self.assertEquals({'keep': 'value'}, utils.remove_None(data))
