@@ -2,7 +2,6 @@
 
 __all__ = [
     "Zone",
-    "ZoneField",
     "Zones",
 ]
 
@@ -22,6 +21,22 @@ class ZonesType(ObjectType):
         data = await cls._handler.read()
         return cls(map(cls._object, data))
 
+    async def create(cls, name: str, description: str=None):
+        """
+        Create a `Zone` in MAAS.
+
+        :param name: The name of the `Zone`.
+        :type name: `str`
+        :param description: A description of the `Zone`.
+        :type description: `str`
+        :returns: The create `Zone`
+        :rtype: `Zone`
+        """
+        params = {'name': name}
+        if description is not None:
+            params['description'] = description
+        return cls._object(await cls._handler.create(**params))
+
 
 class Zones(ObjectSet, metaclass=ZonesType):
     """The set of zones stored in MAAS."""
@@ -37,8 +52,11 @@ class ZoneType(ObjectType):
 class Zone(Object, metaclass=ZoneType):
     """A zone stored in MAAS."""
 
+    id = ObjectField.Checked(
+        "id", check(int), readonly=True)
+
     name = ObjectField.Checked(
-        "name", check(str), check(str))
+        "name", check(str), check(str), pk=True)
     description = ObjectField.Checked(
         "description", check(str), check(str))
 
@@ -46,9 +64,8 @@ class Zone(Object, metaclass=ZoneType):
         return super(Zone, self).__repr__(
             fields={"name", "description"})
 
-
-class ZoneField(ObjectField):
-    """An object field for a `Zone`."""
-
-    def datum_to_value(self, instance, datum):
-        return instance._origin.Zone(datum)
+    async def delete(self):
+        """
+        Deletes the `Zone` from MAAS.
+        """
+        return await self._handler.delete(name=self.name)
